@@ -335,7 +335,7 @@ class Collection extends BaseCollection implements QueueableCollection
      *
      * @param  string|callable|null  $key
      * @param  bool  $strict
-     * @return static
+     * @return static|\Illuminate\Support\Collection
      */
     public function unique($key = null, $strict = false)
     {
@@ -384,7 +384,7 @@ class Collection extends BaseCollection implements QueueableCollection
      */
     public function makeHidden($attributes)
     {
-        return $this->each->addHidden($attributes);
+        return $this->each->makeHidden($attributes);
     }
 
     /**
@@ -398,6 +398,17 @@ class Collection extends BaseCollection implements QueueableCollection
         return $this->each->makeVisible($attributes);
     }
 
+    /**
+     * Append an attribute across the entire collection.
+     *
+     * @param  array|string  $attributes
+     * @return $this
+     */
+    public function append($attributes)
+    {
+        return $this->each->append($attributes);
+    }
+
     /**
      * Get a dictionary keyed by primary keys.
      *
@@ -446,12 +457,12 @@ class Collection extends BaseCollection implements QueueableCollection
     /**
      * Zip the collection together with one or more arrays.
      *
-     * @param  mixed ...$items
+     * @param  mixed  ...$items
      * @return \Illuminate\Support\Collection
      */
     public function zip($items)
     {
-        return $this->toBase()->zip(...func_get_args());
+        return call_user_func_array([$this->toBase(), 'zip'], func_get_args());
     }
 
     /**
@@ -566,7 +577,7 @@ class Collection extends BaseCollection implements QueueableCollection
         if (count($relations) === 0 || $relations === [[]]) {
             return [];
         } elseif (count($relations) === 1) {
-            return array_values($relations)[0];
+            return $relations[0];
         } else {
             return array_intersect(...$relations);
         }
